@@ -1,26 +1,49 @@
 use v5.16;
+
 use strict;
 use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_08';
+  our $VERSION = '0.17_09';
 
   use Zydeco
     authority => 'cpan:SMONFF',
-    #
-    # Only possible since Type::Tiny->version 1.011_009 (unstable)
-    # declare => ['Artwork', 'Collector'],
-    # When Type::Tiny 1.011 will come out, it will be possible to remove quotes
+    # Only possible since Type::Tiny->version 1.011000
+    # When Type::Tiny 1.011 came out, it started to be possible to remove quotes
     # around the attributes types that are custom Zydeco classes of ours
     #   has attr ( type => 'xxx' )
     # See:
     #   - https://rt.cpan.org/Public/Bug/Display.html?id=133448
     #   - https://gitlab.com/smonff/art-world/-/issues/37
     #
+    declare => [ 'Agent', 'Artwork', 'Collector', 'Theory', 'Idea'],
     version   => $VERSION;
   use Carp;
   use utf8;
+  use Config::Tiny;
+  use DDP;
+  use List::Util qw( max );
+  use Math::Round;
+
+  role Abstraction {
+    has discourse ( type => Str );
+    has file! ( type => ArrayRef[ Idea ], );
+    has idea! ( type => Str, is => rw,  trigger => true );
+    has process ( type => ArrayRef );
+    has project ( type => Str );
+    has time ( type => Int );
+    # Here should exist all the possible interractions of Concept entities
+    method initiate_process {
+      return $self->idea;
+    }
+    method insert_to_file {}
+    # etc.
+    method _trigger_idea {
+      push $self->file->@*, $self->idea;
+    }
+  }
+
 
   role Active {
     method participate {
@@ -28,12 +51,11 @@ package Art::World {
     }
   }
 
-
   role Buyer {
-    requires money;  # Num $price
+    requires money;           # Num $price
     method acquire ( Artwork $art ) {
       $self->money( $self->money - $art->value );
-      push @{ $self->collection }, $art;
+      push $self->collection->@*, $art;
       say "I bought for " . $art->value . " worth of art!" ;
     }
 
@@ -46,50 +68,20 @@ package Art::World {
     }
   }
 
-
   # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     # Should be an object of type Agent
-    has owner  ( type => 'ArrayRef[ Collector ]' );
+    has owner  ( type => ArrayRef[Collector] );
     has value  ( is   => rw );
     has status (
       enum            => ['for_sale', 'sold'],
       handles         => 1,
-      default         => 'for_sale'
-    );
+      default         => 'for_sale' );
     method belongs_to {
       return $self->owner;
     }
   }
 
-  role Concept {
-    # Here should exist all the possible interractions of Concept entities
-    method idea_of_project {}
-    method idea_file {}
-    # etc.
-  }
-
-  role Fame {
-    # TODO If an Agent work is  collected, it's reputation should go up
-    method bump_fame( Num $gain = 1 ) {
-      # Dynamic attribute accessor
-      my $attribute = $self->isa( 'Art::World::Work' ) ?
-        'aura' : 'reputation';
-      if ( $self->can( $attribute )) {
-        if ( $self->$attribute + $gain >= 0 ) {
-          $self->$attribute( $self->$attribute + $gain )
-        } else {
-          carp 'You tried to update ' . $attribute . ' to a value smaller ' .
-            'than zero. Nothing changed.';
-        }
-        return $self->$attribute;
-      } else {
-        carp 'No such attribute ' . $attribute .
-          ' or we don\'t manage this kind of entity ' . Meta->get_class( $self );
-      }
-    }
-  }
-
   role Exhibit {
     has public;
     has exhibition ( type => ArrayRef );
@@ -101,7 +93,33 @@ package Art::World {
     }
   }
 
+  role Fame {
+    # TODO If an Agent work is  collected, it's reputation should go up
+    method bump_fame( Num $gain = $self->config->{ FAME }->{ DEFAULT_BUMP } ) {
+      # Dynamic attribute accessor
+      my $attribute = $self->isa( 'Art::World::Work' ) ?
+          'aura' : 'reputation';
+      if ( $self->can( $attribute )) {
+        if ( $self->$attribute + $gain >= 0 ) {
+          $self->$attribute( $self->$attribute + $gain )
+        } else {
+          carp 'You tried to update ' . $attribute . ' to a value smaller ' .
+              'than zero. Nothing changed.';
+        }
+        return $self->$attribute;
+      } else {
+        carp 'No such attribute ' . $attribute .
+            ' or we don\'t manage this kind of entity ' . Meta->get_class( $self );
+      }
+    }
+  }
+
+  role Language {
+    method speak {}
+  }
+
   role Manager {
+
     method organize {}
   }
 
@@ -127,189 +145,218 @@ package Art::World {
     }
   }
 
-  class Abstraction with Concept {
-    has idea!, process, file!, discourse, time, project;
+  role Writing {
+    method write ( Theory $concepts ) {}
   }
 
-  class Event with Fame {
-    has place;
-    has datetime;
-    # "guests"
-    has participants;
-    class Opening {
-      has treat;
-      has smalltalk;
-    };
-    class Sex;
-  }
+  class Art {
 
-  class Playground {
+    has config (
+      is => ro,
+      lazy => true,
+      default => sub { Config::Tiny->read( './art.conf' )}
+    );
 
-    class Collective;
-    class Magazine {
-      has reader;
-    };
+    # TODO an implemented project (Work, Exhibition) should inherit of this
+    # TODO some stuff should extends this
+    abstract class Concept {
+      class Idea  with Abstraction {
 
+      }
+      class Theory  with Abstraction { }
+    }
 
-    class Place with Space, Fame {
-      class Institution {
+    class Event with Fame {
+      has place;
+      has datetime;
+      # "guests"
+      has participants;
+
+      class Opening {
+        has treat;
+        has smalltalk;
+      }
+
+      class Sex;
+    }
+
+    class Playground {
+
+      class Collective;
+      class Magazine {
+        has reader;
+      }
+
+      class Place with Space, Fame {
+        class Institution {
+
+          class School {
+            has student;
+            has teachers;
+          }
+
+          class Gallery with Exhibit, Buyer {
+
+            has artwork (  type => ArrayRef );
+            has artist (  type => ArrayRef );
+            has event ( type => ArrayRef );
+            has owner;
+            has money;
+
+            # Should be moved to an Opening role
+            method serve {
+              say "What would you drink?";
+              p $self->config;
+            }
+          }
+
+          class Museum with Exhibit;
 
-        class School {
-          has student;
-          has teachers;
         }
 
-        class Gallery with Exhibit, Buyer {
+        class Squat with Underground;
+        class Workshop;
+      }
 
-          has artwork (  type => ArrayRef );
-          has artist (  type => ArrayRef );
-          has event ( type => ArrayRef );
-          has owner;
-          has money;
+      class Website;
+    }
 
-          # Should be moved to an Opening role
-          method serve {
-            say "What would you drink?";
+    class Agent with Active, Fame {
+      # Should be required but will be moved to the Crudable area
+      has id         ( type => Int );
+      has name!      ( type => Str );
+      has reputation ( is => rw, type => PositiveOrZeroNum );
+
+      # TODO Should be done during an event
+      # TODO In case the networker is a Manager, the reputation bump
+      # should be higher
+      method networking( ArrayRef $people ) {
+        my $highest_reputation = max map { $_-> reputation } @$people;
+        my $bump = $highest_reputation > 1 ?
+            round( $highest_reputation * 10 / 100) :
+            $self->config->{ FAME }->{ DEFAULT_BUMP };
+        for my $agent ( @$people ) {
+          $agent->bump_fame( $bump );
+        }
+      }
+
+      class Artist {
+
+        has artworks   ( type => ArrayRef );
+        has collectors ( type => ArrayRef[Collector], default => sub { [] } );
+        has collected  ( type => Bool, default => false, is => rw );
+        has status (
+          enum => [ 'underground', 'homogenic' ],
+          handles => 1,
+          default => sub {
+            my $self = shift;
+            $self->has_collectors ? 'homogenic' : 'underground' });
+
+        method create {
+          say $self->name . " create !";
+        }
+
+        method have_idea {
+          say $self->name . ' have shitty idea' if true;
+        }
+
+        method perform {}
+
+        # factory underground_artist does underground
+
+        method has_collectors {
+          if ( scalar $self->collectors->@* > 1 ) {
+            $self->collected( true );
           }
         }
-
-        class Museum with Exhibit;
-
-      }
-      class Squat with Underground;
-      class Workshop;
-    }
-    class Website;
-  }
-
-  class Agent with Active, Fame {
-    # Should be required but will be moved to the Crudable area
-    has id         ( type => Int );
-    has name!      ( type => Str );
-    has reputation ( is => rw, type => PositiveOrZeroNum );
-    class Artist {
-
-      has artworks   ( type => ArrayRef );
-      has collectors ( type => 'ArrayRef[Collector]', default => sub { [] } );
-      has collected  ( type => Bool, default => false, is => rw );
-      has status (
-        enum => [ 'underground', 'homogenic' ],
-        handles => 1,
-        default => sub {
-          my $self = shift;
-          $self->has_collectors ? 'homogenic' : 'underground' });
-
-      method create {
-        say $self->name . " create !";
       }
 
-      method have_idea {
-        say $self->name . ' have shitty idea' if true;
+
+      class Collector with Active, Buyer {
+        has money! ( type => Num, is => rw );
+        has collection (
+          type    => ArrayRef[Artwork, 0 ],
+          default => sub { [] },
+          is      => rw, );
       }
 
-      # factory underground_artist does underground
+      class Critic with Language, Writing {};
 
-      method has_collectors {
-        if ( scalar @{ $self->collectors }  > 1 ) {
-          $self->collected( true );
+      class Curator with Manager, Writing {
+        has exhibition( type  => ArrayRef );
+        method select( Artwork $art ) {
+          push $self->exhibition->@*, $art;
+        }
+        method define( Theory $thematic ) { }
+        method setup( Place $space ) { }
+        method write( Theory $catalog ) { }
+      }
+
+      class Director with Manager {    }
+
+      class Public {
+        method visit {
+          say "I visited";
         }
       }
-
-      # method new ($id, $name, @artworks, @collectors) {
-      #     self.bless(:$id, :$name, :@artworks, :@collectors);
-      # }
+      #use Art::Behavior::Crudable;
+      # does Art::Behavior::Crudable;
+      # has relations
     }
 
 
-    class Collector with Active, Buyer {
-      has money! ( type => Num, is => rw );
-      has collection (
-        type    => 'ArrayRef[Artwork, 0 ]',
-        default => sub { [] },
-        is      => rw,
-      );
-    }
+    class Work with Fame {
 
-    class Critic;
-
-    class Curator with Manager {
-      has exhibition(
-        type  => ArrayRef,
-      );
-      method select( Artwork $art ) {
-        push @{ $self->exhibition }, $art;
-      }
-      method define( Theory $thematic ) { }
-      method setup( Place $space ) { }
-      method write( Theory $catalog) { }
-    };
-
-    class Public {
-      method visit {
-        say "I visited";
-      }
-    }
-    #use Art::Behavior::Crudable;
-    # does Art::Behavior::Crudable;
-    # has relations
-  }
-
-
-  class Work with Fame {
-
-    has creation_date;
-    has creator(
-      is   => ro,
-      # TODO Should be an ArrayRef of Agents
-      type => ArrayRef[ Object ]
-    );
-
-    has title(
-      is   => ro,
-      type => Str,
-    );
-
-    # Same as Agent->reputation
-    has aura( is => rw, type => PositiveOrZeroNum );
-
-    class Article;
-
-    class Artwork with Showable, Collectionable  {
-      has material;
-      has size;
-    }
-
-    class Book;
-
-    class Exhibition extends Event {
-      has curator! (
+      has creation_date;
+      has creator(
         is   => ro,
-        type => 'ArrayRef[ Agent ]'
-      );
-    };
-  }
+        # TODO Should be an ArrayRef of Agents
+        type => ArrayRef[ Object ] );
 
-  # Looks like the Art::World::Meta toolkit
-  class Meta {
-    method get_class( Object $klass ) {
-      return ref $klass;
+      has title(
+        is   => ro,
+        type => Str );
+
+      # Same as Agent->reputation
+      has aura( is => rw, type => PositiveOrZeroNum );
+
+      class Article;
+
+      class Artwork with Showable, Collectionable  {
+        has material;
+        has size;
+      }
+
+      class Book;
+
+      class Exhibition extends Event {
+        has curator! (
+          is   => ro,
+          type => ArrayRef[ Agent ] );
+      }
     }
 
-    method get_set_attributes_only( Object $clazz ) {
-      return keys %{ $clazz };
-    }
+    # Looks like the Art::World::Meta toolkit
+    class Meta {
+      method get_class( Object $klass ) {
+        return ref $klass;
+      }
 
-    method get_all_attributes( Object $claxx ) {
-      return keys( %{
-        'Moo'->_constructor_maker_for(
-          $self->get_class( $claxx )
-        )->all_attribute_specs
-      });
+      method get_set_attributes_only( Object $clazz ) {
+        return keys %{ $clazz };
+      }
+
+      method get_all_attributes( Object $claxx ) {
+        return keys( %{
+          'Moo'->_constructor_maker_for(
+            $self->get_class( $claxx )
+              )->all_attribute_specs
+                     });
+      }
     }
   }
 }
 
-
 1;
 __END__
 
@@ -321,7 +368,7 @@ Art::World - Agents interactions modeling  🎨
 
 =head1 SYNOPSIS
 
-  use Art::World;
+use Art::World;
 
   my $artwork = Art::World->new_artwork(
     creator => [ $artist, $another_artist ]  ,
@@ -341,6 +388,11 @@ understand how this is an artwork using programming.
 
 =head1 ROLES
 
+=head2 Abstraction
+
+This is were all kind of weird phenomenons happen. See the Manual about how it
+works.
+
 =head2 Active
 
 Provide a C<participate> method.
@@ -355,8 +407,6 @@ as somebody in the art world that buy but doesn't sale.
 
 If it's collectionable, it can go to a C<Collector> collection or in a C<Museum>.
 
-=head2 Concept
-
 =head2 Exhibit
 
 Role for L<C<Places>|Art::World/"Place"> that display some  L<C<Artworks>|Art::World/"Artwork">.
@@ -419,7 +469,7 @@ be exhibited only if it reached the C<Showable> stage.
 
 =head2 Agent
 
-They are the activists of the Art World, well known as the I<wildlife>.
+They are the activists of the Art World, previously known as the I<Wildlife>.
 
   my $agent = Art::World->new_agent( name => $f->person_name );
 
@@ -428,6 +478,12 @@ They are the activists of the Art World, well known as the I<wildlife>.
 A generic entity that can be any activist of the C<Art::World>. Provides all
 kind of C<Agent> classes and roles.
 
+The C<Agent> got an a C<networking( $people )> method. When it is passed and
+C<ArrayRef> of various implementation classes of C<Agents> (C<Artist>,
+C<Curator>, etc.) it bumps the C<reputation> atributes of all of 1/10 of the
+C<Agent> with the highest reputation. If this reputation is less than 1, it is
+rounded to the C<$self->config->{ FAME }->{ DEFAULT_BUMP }> constant.
+
 =head2 Art
 
 Will be what you decide it to be depending on how you combine all the entities.
@@ -436,12 +492,6 @@ Will be what you decide it to be depending on how you combine all the entities.
 
 Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.
 
-=head2 Artwork
-
-The base thing producted by artists. Artwork is subclass of
-L<C<Work>Art::World::Work> that have a C<Showable> and C<Collectionable> role.
-
-
 =head2 Artist
 
 The artist got a lots of wonderful powers:
@@ -459,6 +509,11 @@ change in time.
 
 =back
 
+=head2 Artwork
+
+The base thing producted by artists. Artwork is subclass of
+L<C<Work>Art::World::Work> that have a C<Showable> and C<Collectionable> role.
+
 =head2 Book
 
 Where a lot of theory is written by C<Critics>
@@ -469,6 +524,10 @@ Where a lot of theory is written by C<Critics>
 
 They do stuff together. You know, art is not about lonely C<Artists> in their C<Workshop>.
 
+=head2 Concept
+
+C<Concept> is an abstract class that does the C<Abstraction> role.
+
 =head2 Critic
 
 =head2 Curator
@@ -489,6 +548,10 @@ Just another kind of L<C<Place>|Art::World/"Place">, mostly commercial.
 Since it implements the L<C<Buyer>|Art::World/"Buyer"> role, a gallery can both
 C<acquire()> and C<sell()>.
 
+=head2 Idea
+
+When some abstractions starts to become something in the mind of an C<Agent>
+
 =head2 Institution
 
 A C<Place> that came out of the C<Underground>.
@@ -515,6 +578,10 @@ A generic space where C<Art::World> C<Agents> can do all kind of weird things.
 
 =head2 Squat
 
+=head2 Theory
+
+When some abstract concept turns to some said or written stuff.
+
 =head2 Website
 
 =head2 Work
@@ -537,6 +604,8 @@ inspired by L<this Perl Monks thread|https://www.perlmonks.org/?node_id=1043195>
 
 =head2 get_class( Object $klass )
 
+Returns the class of the object.
+
 =head2 get_set_attributes_only( Object $clazz )
 
 Returns only attributes that are set for a particular object.
